dataWPstr = [ ... 
'  Begin waypoint control at t= 111.00                            (wplog)'
'  The current location (N,E) = 4072819.2      , 605663.3         (wplog)'
'  The next waypoint          = 4073350.3      , 605863.2         (wplog)'
'  reached at t = 479.20                                          (wplog)'
 ];
