dataWPstr = [ ... 
'  Begin waypoint control at t= 131.21                            (wplog)'
'  The current location (N,E) = 4071853.3      , 605194.0         (wplog)'
'  The next waypoint          = 4073350.3      , 605863.2         (wplog)'
 ];
