dataWPstr = [ ... 
'  Begin waypoint control at t= 97.21                             (wplog)'
'  The current location (N,E) = 4073356.3      , 605956.3         (wplog)'
'  The next waypoint          = 4073737.1      , 606781.9         (wplog)'
'  reached at t = 691.19                                          (wplog)'
 ];
